@@ -6,6 +6,7 @@ enum Platform {
     #[counter(group = "mobile")]
     Android,
     #[counter(group = "mobile")]
+    #[allow(clippy::upper_case_acronyms)]
     IOS,
     #[counter(group = "desktop")]
     Windows,
@@ -21,8 +22,11 @@ enum Platform {
 fn main() {
     let mut counter = Platform::counter();
     counter.record(&Platform::Android);
+    counter.record(&Platform::Android);
     counter.record(&Platform::Windows);
     counter.record(&Platform::IOS);
     counter.record(&Platform::Others);
+    assert_eq!(counter.check(&Platform::Android), Some(2));
     println!("{:?}", counter.to_map());
+    println!("{:?}", counter.to_group_map());
 }
